@@ -17,6 +17,7 @@
 from itertools import count
 from threading import Thread
 from collections import Callable
+from functools import update_wrapper
 from multiprocessing import Process, Pipe
 
 from .pebble import ThreadTask, ProcessTask, thread_worker, process_worker
@@ -28,6 +29,7 @@ class AsynchronousWrapper(object):
         self._counter = count()
         self.callback = callback
         self.error_callback = error_callback
+        update_wrapper(self, function)
 
     def __call__(self, *args, **kwargs):
         t = ThreadTask(next(self._counter),
@@ -73,6 +75,7 @@ class ConcurrentWrapper(object):
         self.timeout = timeout
         self.callback = callback
         self.error_callback = error_callback
+        update_wrapper(self, function)
 
     def __call__(self, *args, **kwargs):
         reader, writer = Pipe(duplex=False)
